@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2014-2016 BigML
+# Copyright 2014-2020 BigML
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -125,13 +125,12 @@ def local_centroid(clusters, test_reader, output, args,
 
     """
     # Only one cluster at present
-    local_cluster = Cluster(clusters[0])
-    test_set_header = test_reader.has_headers()
+    local_cluster = Cluster(clusters[0], api=args.retrieve_api_)
     for input_data in test_reader:
         input_data_dict = test_reader.dict(input_data, filtering=False)
         try:
             centroid_info = local_cluster.centroid(
-                input_data_dict, by_name=test_set_header)
+                input_data_dict)
         except Exception:
             centroid_info = {'centroid_name': NO_CENTROID}
         write_centroid(centroid_info['centroid_name'], output,
