@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2012-2016 BigML
+# Copyright 2012-2020 BigML
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -406,3 +406,174 @@ def are_logistic_regressions_created(path, number_of_logistic_regressions):
             logistic_ids
     except IOError:
         return False, logistic_ids
+
+
+def are_linear_regressions_created(path, number_of_linear_regressions):
+    """Checks existence and reads the linear regression ids
+       from the linear regressions file in the
+       path directory
+
+    """
+    linear_ids = []
+    try:
+        with open("%s%slinear_regressions" % (path, os.sep)) as \
+            linear_file:
+            for line in linear_file:
+                linear = line.strip()
+                try:
+                    linear_id = bigml.api.get_linear_regression_id( \
+                        linear)
+                    linear_ids.append(linear_id)
+                except ValueError:
+                    return False, linear_ids
+        return len(linear_ids) == number_of_linear_regressions, \
+            linear_ids
+    except IOError:
+        return False, linear_ids
+
+
+def are_scripts_created(path, number_of_scripts):
+    """Checks existence and reads the scripts ids from the scripts file in the
+       path directory
+
+    """
+    script_ids = []
+    try:
+        with open("%s%sscripts" % (path, os.sep)) as scripts_file:
+            for line in scripts_file:
+                script = line.strip()
+                try:
+                    script_id = bigml.api.get_script_id(script)
+                    script_ids.append(script_id)
+                except ValueError:
+                    return False, script_ids
+        if len(script_ids) == number_of_scripts:
+            return True, script_ids
+        else:
+            return False, script_ids
+    except IOError:
+        return False, script_ids
+
+
+def is_execution_created(path):
+    """Checks existence and reads the execution id from the execution file in
+        the path directory
+
+    """
+    execution_id = None
+    try:
+        with open("%s%sexecution" % (path, os.sep)) as execution_file:
+            execution_id = execution_file.readline().strip()
+            try:
+                execution_id = bigml.api.get_execution_id(execution_id)
+                return True, execution_id
+            except ValueError:
+                return False, None
+    except IOError:
+        return False, None
+
+
+def is_library_created(path):
+    """Checks existence and reads the library id from the library file in
+        the path directory
+
+    """
+    library_id = None
+    try:
+        with open("%s%slibrary" % (path, os.sep)) as library_file:
+            library_id = library_file.readline().strip()
+            try:
+                library_id = bigml.api.get_library_id(library_id)
+                return True, library_id
+            except ValueError:
+                return False, None
+    except IOError:
+        return False, None
+
+
+def are_topic_models_created(path, number_of_topic_models):
+    """Checks existence and reads the topic model ids from the
+       topic models file in the
+       path directory
+
+    """
+    topic_model_ids = []
+    try:
+        with open("%s%stopic_models" % (path, os.sep)) as topic_models_file:
+            for line in topic_models_file:
+                topic_model = line.strip()
+                try:
+                    topic_model_id = bigml.api.get_topic_model_id(topic_model)
+                    topic_model_ids.append(topic_model_id)
+                except ValueError:
+                    return False, topic_model_ids
+        return len(topic_model_ids) == number_of_topic_models, topic_model_ids
+    except IOError:
+        return False, topic_model_ids
+
+
+def is_batch_topic_distribution_created(path):
+    """Checks existence and reads the batch topic distribution id from the
+       batch_topic_distribution file in the path directory
+
+    """
+    batch_topic_distribution_id = None
+    try:
+        with open("%s%sbatch_topic_distribution"
+                  % (path, os.sep)) as batch_prediction_file:
+            batch_topic_distribution_id = \
+                batch_prediction_file.readline().strip()
+            try:
+                batch_topic_distribution_id = \
+                    bigml.api.get_batch_topic_distribution_id( \
+                    batch_topic_distribution_id)
+                return True, batch_topic_distribution_id
+            except ValueError:
+                return False, None
+    except IOError:
+        return False, None
+
+
+def are_time_series_created(path, number_of_time_series):
+    """Checks existence and reads the time-series ids from the
+       time-series file in the
+       path directory
+
+    """
+    time_series_ids = []
+    try:
+        with open("%s%stime_series" % (path, os.sep)) as time_series_file:
+            for line in time_series_file:
+                time_series = line.strip()
+                try:
+                    time_series_id = bigml.api.get_time_series_id(time_series)
+                    time_series_ids.append(time_series_id)
+                except ValueError:
+                    return False, time_series_ids
+        return len(time_series_ids) == number_of_time_series, time_series_ids
+    except IOError:
+        return False, time_series_ids
+
+
+def are_deepnets_created(path, number_of_deepnets):
+    """Checks existence and reads the deepnet ids
+       from the deepnets file in the
+       path directory
+
+    """
+    deepnet_ids = []
+    try:
+        with open("%s%sdeepnets" % (path, os.sep)) as \
+            deepnets_file:
+            for line in deepnets_file:
+                deepnet = line.strip()
+                try:
+                    deepnet_id = bigml.api.get_deepnet_id( \
+                        deepnet)
+                    deepnet_ids.append(deepnet_id)
+                except ValueError:
+                    return False, deepnet_ids
+        return len(deepnet_ids) == number_of_deepnets, \
+            deepnet_ids
+    except IOError:
+        return False, deepnet_ids
