@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2012-2016 BigML
+# Copyright 2012-2020 BigML
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -26,6 +26,11 @@ import gc
 import shutil
 
 import bigml.api
+
+from bigml.model import Model
+from bigml.basemodel import retrieve_resource
+from bigml.fields import Fields
+
 import bigmler.utils as u
 import bigmler.resources as r
 import bigmler.labels as l
@@ -34,23 +39,27 @@ import bigmler.processing.sources as ps
 import bigmler.processing.datasets as pd
 import bigmler.processing.models as pm
 
-from bigml.model import Model
-from bigml.basemodel import retrieve_resource
-from bigml.fields import Fields
-
 from bigmler.evaluation import evaluate, cross_validate
 from bigmler.defaults import DEFAULTS_FILE
 from bigmler.prediction import predict, combine_votes, remote_predict
-from bigmler.prediction import (OTHER, COMBINATION,
-                                THRESHOLD_CODE)
+from bigmler.prediction import OTHER, COMBINATION
 from bigmler.reports import clear_reports, upload_reports
-from bigmler.command import Command, get_stored_command
+from bigmler.command import get_context
 from bigmler.command import COMMAND_LOG, DIRS_LOG, SESSIONS_LOG
 
 
 LOG_FILES = [COMMAND_LOG, DIRS_LOG, u.NEW_DIRS_LOG]
 MINIMUM_MODEL = "full=false"
 
+DEFAULT_OUTPUT = 'predictions.csv'
+
+SETTINGS = {
+    "command_log": COMMAND_LOG,
+    "sessions_log": SESSIONS_LOG,
+    "dirs_log": DIRS_LOG,
+    "default_output": DEFAULT_OUTPUT,
+    "defaults_file": DEFAULTS_FILE}
+
 
 def belongs_to_ensemble(model):
     """Checks if a model is part of an ensemble
@@ -87,22 +96,6 @@ def has_source(args):
             args.train_stdin)
 
 
-
-def command_handling(args, log=COMMAND_LOG):
-    """Rebuilds command string, logs it for --resume future requests and
-       parses it.
-
-    """
-    # Create the Command object
-    command = Command(args, None)
-
-    # Resume calls are not logged
-    if not command.resume:
-        u.sys_log_message(command.command.replace('\\', '\\\\'), log_file=log)
-
-    return command
-
-
 def clear_log_files(log_files):
     """Clear all contents in log files
 
@@ -186,50 +179,17 @@ def main_dispatcher(args=sys.argv[1:]):
     if "--clear-logs" in args:
         clear_log_files(LOG_FILES)
 
-    command = command_handling(args, COMMAND_LOG)
-
-    # Parses command line arguments.
-    command_args = a.parse_and_check(command)
-    default_output = ('evaluation' if command_args.evaluate
-                      else 'predictions.csv')
-    resume = command_args.resume
-    if command_args.resume:
-        command_args, session_file, output_dir = get_stored_command(
-            args, command_args.debug, command_log=COMMAND_LOG,
-            dirs_log=DIRS_LOG, sessions_log=SESSIONS_LOG)
-        default_output = ('evaluation' if command_args.evaluate
-                          else 'predictions.csv')
-        if command_args.predictions is None:
-            command_args.predictions = os.path.join(output_dir,
-                                                    default_output)
-    else:
-        if command_args.output_dir is None:
-            command_args.output_dir = a.NOW
-        if command_args.predictions is None:
-            command_args.predictions = os.path.join(command_args.output_dir,
-                                                    default_output)
-        if len(os.path.dirname(command_args.predictions).strip()) == 0:
-            command_args.predictions = os.path.join(command_args.output_dir,
-                                                    command_args.predictions)
-        directory = u.check_dir(command_args.predictions)
-        session_file = os.path.join(directory, SESSIONS_LOG)
-        u.log_message(command.command + "\n", log_file=session_file)
-        try:
-            shutil.copy(DEFAULTS_FILE, os.path.join(directory, DEFAULTS_FILE))
-        except IOError:
-            pass
-        u.sys_log_message(u"%s\n" % os.path.abspath(directory),
-                          log_file=DIRS_LOG)
-
-    # Creates the corresponding api instance
-    api = a.get_api_instance(command_args, u.check_dir(session_file))
+    settings = {}
+    settings.update(SETTINGS)
+    if '--evaluate' in args:
+        settings.update({"default_output": "evaluation"})
 
+    command_args, command, api, session_file, resume = get_context(args,
+                                                                   settings)
+    # the predictions flag prevails to store the results
     if (a.has_train(command_args) or a.has_test(command_args)
             or command_args.votes_dirs):
-        output_args = a.get_output_args(api, command_args, resume)
-        a.transform_args(command_args, command.flags, api,
-                         command.user_defaults)
-        compute_output(**output_args)
+        compute_output(api, command_args)
     u.log_message("_" * 80 + "\n", log_file=session_file)
 
 
@@ -254,12 +214,12 @@ def compute_output(api, args):
     # variables from command-line options
     resume = args.resume_
     model_ids = args.model_ids_
-    output = args.predictions
+    output = args.output
     dataset_fields = args.dataset_fields_
 
     check_args_coherence(args)
-
     path = u.check_dir(output)
+
     session_file = "%s%s%s" % (path, os.sep, SESSIONS_LOG)
     csv_properties = {}
     # If logging is required set the file for logging
@@ -302,6 +262,8 @@ def compute_output(api, args):
             api, args, resume,
             csv_properties=csv_properties, multi_label_data=multi_label_data,
             session_file=session_file, path=path, log=log)
+    if source is not None:
+        args.source = bigml.api.get_source_id(source)
     if args.multi_label and source:
         multi_label_data = l.get_multi_label_data(source)
         (args.objective_field,
@@ -313,7 +275,7 @@ def compute_output(api, args):
                                                   fields,
                                                   multi_label_fields)
     if fields and args.export_fields:
-       fields.summary_csv(os.path.join(path, args.export_fields))
+        fields.summary_csv(os.path.join(path, args.export_fields))
     if args.dataset_file:
         # dataset is retrieved from the contents of the given local JSON file
         model_dataset, csv_properties, fields = u.read_local_resource(
@@ -415,7 +377,7 @@ def compute_output(api, args):
         other_label = get_metadata(dataset, 'other_label',
                                    other_label)
     if fields and args.export_fields:
-       fields.summary_csv(os.path.join(path, args.export_fields))
+        fields.summary_csv(os.path.join(path, args.export_fields))
     if args.model_file:
         # model is retrieved from the contents of the given local JSON file
         model, csv_properties, fields = u.read_local_resource(
@@ -432,7 +394,8 @@ def compute_output(api, args):
         model_ids = ensemble['object']['models'][:]
         ensemble_ids = [ensemble['resource']]
         models = model_ids[:]
-        model = retrieve_resource(bigml.api.BigML(storage='./storage'),
+
+        model = retrieve_resource(args.retrieve_api_,
                                   models[0],
                                   query_string=r.ALL_FIELDS_QS)
         models[0] = model
@@ -467,7 +430,7 @@ def compute_output(api, args):
         if (isinstance(model, basestring) or
                 bigml.api.get_status(model)['code'] != bigml.api.FINISHED):
             if not args.evaluate and not a.has_train(args) and \
-                    not a.has_test(args) :
+                    not a.has_test(args):
                 query_string = MINIMUM_MODEL
             elif not args.test_header:
                 query_string = r.ALL_FIELDS_QS
@@ -493,6 +456,9 @@ def compute_output(api, args):
     # them yet and need them
     if model and not args.evaluate and (a.has_test(args) or
                                         args.export_fields):
+        # if we are using boosted ensembles to predict, activate boosting
+        if model['object'].get('boosted_ensemble'):
+            args.boosting = True
         # If more than one model, use the full field structure
         if (not single_model and not args.multi_label and
                 belongs_to_ensemble(model)):
@@ -548,7 +514,7 @@ def compute_output(api, args):
         # in bigml.com except when --no-batch flag is set on or multi-label
         # or max-categories are used
         if (args.remote and not args.no_batch and not args.multi_label
-                and not args.method in [THRESHOLD_CODE, COMBINATION]):
+                and not args.method == COMBINATION):
             # create test source from file
             test_name = "%s - test" % args.name
             if args.test_source is None:
