@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2012-2016 BigML
+# Copyright 2012-2020 BigML
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -24,11 +24,6 @@ import gc
 
 import bigml.api
 
-import bigmler.utils as u
-import bigmler.checkpoint as c
-
-
-
 from bigml.model import Model
 from bigml.multimodel import MultiModel, read_votes
 from bigml.ensemble import Ensemble
@@ -37,6 +32,9 @@ from bigml.io import UnicodeWriter
 from bigml.multivote import (PLURALITY_CODE, THRESHOLD_CODE, MultiVote,
                              ws_confidence)
 
+import bigmler.utils as u
+import bigmler.checkpoint as c
+
 from bigmler.tst_reader import TstReader as TestReader
 from bigmler.resources import (FIELDS_QS, ALL_FIELDS_QS, BRIEF_FORMAT,
                                NORMAL_FORMAT, FULL_FORMAT)
@@ -45,8 +43,10 @@ from bigmler.utils import (log_created_resources, check_resource_error, dated,
                            get_url, log_message)
 
 MAX_MODELS = 10
-AGGREGATION = -1
+BOOSTING = -1
 COMBINATION = -2
+AGGREGATION = -3
+
 COMBINATION_LABEL = 'combined'
 OTHER = "***** other *****"
 
@@ -127,6 +127,9 @@ def write_prediction(prediction, output=sys.stdout,
     if isinstance(prediction, list):
         prediction, confidence = ((prediction[0], None) if len(prediction) == 1
                                   else prediction)
+    if isinstance(prediction, dict):
+        confidence = prediction.get("confidence", prediction.get("probability"))
+        prediction = prediction["prediction"]
 
     row = []
     # input data is added if prediction format is BRIEF (no confidence) or FULL
@@ -157,7 +160,7 @@ def prediction_to_row(prediction, prediction_info=NORMAL_FORMAT):
     prediction_class = prediction['objective_fields'][0]
     tree = prediction.get('prediction_path', prediction)
     row = [prediction['prediction'][prediction_class]]
-    if not prediction_info == BRIEF_FORMAT:
+    if prediction_info != BRIEF_FORMAT:
         row.append(prediction.get('confidence', tree.get('confidence', 0)))
         distribution = None
         if 'objective_summary' in tree:
@@ -194,7 +197,7 @@ def combine_votes(votes_files, to_prediction, to_file, method=0,
             multivote = votes[index]
             input_data = (None if input_data_list is None
                           else input_data_list[index])
-            write_prediction(multivote.combine(method, True), output,
+            write_prediction(multivote.combine(method, full=True), output,
                              prediction_info, input_data, exclude)
 
 
@@ -208,7 +211,6 @@ def remote_predict_models(models, test_reader, prediction_file, api, args,
     prediction_args = {
         "tags": args.tag
     }
-    test_set_header = test_reader.has_headers()
     if output_path is None:
         output_path = u.check_dir(prediction_file)
     message_logged = False
@@ -237,7 +239,6 @@ def remote_predict_models(models, test_reader, prediction_file, api, args,
                 for input_data in raw_input_data_list:
                     input_data_dict = test_reader.dict(input_data)
                     prediction = api.create_prediction(model, input_data_dict,
-                                                       by_name=test_set_header,
                                                        wait_time=0,
                                                        args=prediction_args)
                     u.check_resource_error(prediction,
@@ -269,7 +270,6 @@ def remote_predict_ensemble(ensemble_id, test_reader, prediction_file, api,
         "tags": args.tag,
         "combiner": args.method
     }
-    test_set_header = test_reader.has_headers()
     if output_path is None:
         output_path = u.check_dir(prediction_file)
 
@@ -285,7 +285,6 @@ def remote_predict_ensemble(ensemble_id, test_reader, prediction_file, api,
                 input_data_dict = test_reader.dict(input_data)
                 prediction = api.create_prediction(ensemble_id,
                                                    input_data_dict,
-                                                   by_name=test_set_header,
                                                    wait_time=0,
                                                    args=prediction_args)
                 prediction = u.check_resource(prediction,
@@ -305,15 +304,18 @@ def local_predict(models, test_reader, output, args, options=None,
 
     """
     single_model = len(models) == 1
-    test_set_header = test_reader.has_headers()
-    kwargs = {"by_name": test_set_header, "with_confidence": True,
+    kwargs = {"full": True,
               "missing_strategy": args.missing_strategy}
     if single_model:
-        local_model = Model(models[0])
+        local_model = Model(models[0], api=args.retrieve_api_)
     else:
-        local_model = Ensemble(models, max_models=args.max_batch_models)
+        local_model = Ensemble(models, max_models=args.max_batch_models,
+                               api=args.retrieve_api_)
         kwargs.update({"method": args.method, "options": options,
                        "median": args.median})
+    if args.operating_point_:
+        kwargs.update({"operating_point": args.operating_point_})
+
     for input_data in test_reader:
         input_data_dict = dict(zip(test_reader.raw_headers, input_data))
         prediction = local_model.predict(
@@ -321,8 +323,8 @@ def local_predict(models, test_reader, output, args, options=None,
         if single_model and args.median and local_model.tree.regression:
             # only single models' predictions can be based on the median value
             # predict
-            prediction[0] = prediction[-1]
-        write_prediction(prediction[0: 2],
+            prediction["prediction"] = prediction["median"]
+        write_prediction(prediction,
                          output,
                          args.prediction_info, input_data, exclude)
 
@@ -338,8 +340,7 @@ def retrieve_models_split(models_split, api, query_string=FIELDS_QS,
     complete_models = []
     if models_order is None:
         models_order = []
-    for index in range(len(models_split)):
-        model = models_split[index]
+    for model in models_split:
         if (isinstance(model, basestring) or
                 bigml.api.get_status(model)['code'] != bigml.api.FINISHED):
             try:
@@ -411,10 +412,10 @@ def aggregate_multivote(multivote, options, labels, models_per_label, ordered,
         predictions = []
         for label_prediction in label_predictions:
             label_multivote = MultiVote(label_prediction)
-            prediction, confidence = label_multivote.combine(
-                method=AGGREGATION, with_confidence=True, options=options)
-            predictions.append({'prediction': prediction,
-                                'confidence': confidence})
+            prediction_info = label_multivote.combine(
+                method=AGGREGATION, full=True, options=options)
+            predictions.append({'prediction': prediction_info["prediction"],
+                                'confidence': prediction_info["confidence"]})
     for vote_index in range(0, len(predictions)):
         if ast.literal_eval(predictions[vote_index]['prediction']):
             prediction_list.append(labels[vote_index])
@@ -476,7 +477,6 @@ def local_batch_predict(models, test_reader, prediction_file, api, args,
     max_models = args.max_batch_models
     if labels is None:
         labels = []
-    test_set_header = test_reader.has_headers()
     if output_path is None:
         output_path = u.check_dir(prediction_file)
     if output is None:
@@ -520,7 +520,7 @@ def local_batch_predict(models, test_reader, prediction_file, api, args,
             gc.collect()
             try:
                 votes = local_model.batch_predict(
-                    raw_input_data_list, output_path, by_name=test_set_header,
+                    raw_input_data_list, output_path,
                     reuse=True, missing_strategy=args.missing_strategy,
                     headers=test_reader.raw_headers, to_file=(not args.fast),
                     use_median=args.median)
@@ -571,8 +571,8 @@ def local_batch_predict(models, test_reader, prediction_file, api, args,
             # prediction
             prediction = combine_multivote(multivote, other_label=other_label)
         else:
-            prediction = multivote.combine(method=method, with_confidence=True,
-                                           options=options)
+            prediction = multivote.combine(method=method, options=options,
+                                           full=True)
 
         write_prediction(prediction, output, args.prediction_info, input_data,
                          exclude)
@@ -611,8 +611,7 @@ def predict(models, fields, args, api=None, log=None,
         # For instance,
         #     model_50c0de043b563519830001c2_predictions.csv
         # Predictions are computed individually only if no_batch flag is set
-        if (args.remote and args.no_batch and not args.multi_label
-                and args.method != THRESHOLD_CODE):
+        if args.remote and args.no_batch and not args.multi_label:
             if args.ensemble is not None:
                 remote_predict_ensemble(args.ensemble, test_reader,
                                         prediction_file, api, args, resume,
@@ -632,15 +631,26 @@ def predict(models, fields, args, api=None, log=None,
             options.update(threshold=args.threshold)
             if args.threshold_class is None:
                 local_model = Model(models[0])
-                args.threshold_class = local_model.tree.distribution[0][0]
+                # default class is the first class that appears in the dataset
+                # objective field summary, which might be different from the
+                # objective summary of each model becaus model are built with
+                # sampling
+                objective_field = local_model.objective_id
+                distribution = local_model.tree.fields[objective_field][ \
+                    "summary"]["categories"]
+                args.threshold_class = distribution[0][0]
             options.update(category=args.threshold_class)
         # For a model we build a Model and for a small number of models,
         # we build a MultiModel using all of
         # the given models and issue a combined prediction
-        if (len(models) <= args.max_batch_models and args.fast and
-                not args.multi_label and args.max_categories == 0
+        if (len(models) <= args.max_batch_models \
+                and args.fast and \
+                not args.multi_label and args.max_categories == 0 \
                 and args.method != COMBINATION):
             local_predict(models, test_reader, output, args, options, exclude)
+        elif args.boosting:
+            local_predict(args.ensemble, test_reader, output, args,
+                          options, exclude)
         # For large numbers of models, we split the list of models in chunks
         # and build a MultiModel for each chunk, issue and store predictions
         # for each model and combine all of them eventually.
@@ -682,7 +692,7 @@ def remote_predict(model, test_dataset, batch_prediction_args, args,
                    path=None, log=None):
     """Computes a prediction for each entry in the `test_set`.
 
-       Predictions are computed remotely using the batch predictions call.
+    Predictions are computed remotely using the batch predictions call.
     """
     if args.ensemble is not None and not args.dataset_off:
         model_or_ensemble = args.ensemble
@@ -707,10 +717,10 @@ def remote_predict(model, test_dataset, batch_prediction_args, args,
                 args, api, session_file=session_file, path=path, log=log)
         else:
             batch_predictions = []
-            for index in range(len(test_datasets)):
-                batch_predictions.append(create_batch_prediction(
-                models[index], test_datasets[index], batch_prediction_args,
-                args, api, session_file=session_file, path=path, log=log))
+            for index, test_dataset_n in enumerate(test_datasets):
+                batch_predictions.append(create_batch_prediction( \
+                    models[index], test_dataset_n, batch_prediction_args,
+                    args, api, session_file=session_file, path=path, log=log))
     if not args.no_csv and not args.dataset_off:
         file_name = api.download_batch_prediction(batch_prediction,
                                                   prediction_file)
